@@ -123,9 +123,9 @@ rg_POST <- function(url, req, user, pwd, callopts) {
     authenticate(user = user, password = pwd),
     callopts), body = jsonlite::toJSON(req),
     make_rgbif_ua())
-  if (tmp$status_code > 203) stop(content(tmp, as = "text"), call. = FALSE)
+  if (tmp$status_code > 203) stop(c_utf8(tmp), call. = FALSE)
   stopifnot(tmp$header$`content-type` == 'application/json')
-  content(tmp, as = "text")
+  c_utf8(tmp)
 }
 
 process_keyval <- function(args, type) {
@@ -149,7 +149,8 @@ parse_args <- function(x){
   tmp <- strsplit(x, "\\s")[[1]]
   type <- operator_lkup[[ tmp[2] ]]
   key <- key_lkup[[ tmp[1] ]]
-  list(type = unbox(type), key = unbox(key), value = unbox(tmp[3]))
+  value <- paste0(tmp[3:length(tmp)], collapse = " ")
+  list(type = unbox(type), key = unbox(key), value = unbox(value))
 }
 
 operator_lkup <- list(`=` = 'equals', `&` = 'and', `|` = 'or', `<` = 'lessThan',
